pub enum RebootControllerRequest {
Unblock {
control_handle: RebootControllerControlHandle,
},
Detach {
control_handle: RebootControllerControlHandle,
},
}Expand description
Controls the timing of the reboot into the updated system.
If the client end of a [RebootController] is closed without calling
[RebootController.Detach()], the update attempt will fall back to the
default behavior of rebooting as soon as it is ready.
Variants
Unblock
Informs the update attempt that it may reboot when ready, unblocking a pending reboot if it is already ready to reboot.
If a controller is dropped without sending this request or
[RebootController.Detach], the update attempt reclaims control of the
timing of the reboot, behaving as if the update attempt was not given a
[RebootController] at all.
Fields
control_handle: RebootControllerControlHandleDetach
Informs the update attempt that it should wait to reboot indefinitely,
even if this [RebootController] connection is dropped.
Fields
control_handle: RebootControllerControlHandleImplementations
Sourceimpl RebootControllerRequest
impl RebootControllerRequest
pub fn into_unblock(self) -> Option<RebootControllerControlHandle>
pub fn into_detach(self) -> Option<RebootControllerControlHandle>
Sourcepub fn method_name(&self) -> &'static str
pub fn method_name(&self) -> &'static str
Name of the method defined in FIDL