pub struct RebootControllerProxy { /* private fields */ }Implementations
Sourceimpl RebootControllerProxy
impl RebootControllerProxy
Sourcepub fn new(channel: Channel) -> Self
pub fn new(channel: Channel) -> Self
Create a new Proxy for fuchsia.update.installer/RebootController.
Sourcepub fn take_event_stream(&self) -> RebootControllerEventStream
pub fn take_event_stream(&self) -> RebootControllerEventStream
Get a Stream of events from the remote end of the protocol.
Panics
Panics if the event stream was already taken.
Sourcepub fn unblock(&self) -> Result<(), Error>
pub fn unblock(&self) -> Result<(), Error>
Informs the update attempt that it may reboot when ready, unblocking a pending reboot if it is already ready to reboot.
If a controller is dropped without sending this request or
[RebootController.Detach], the update attempt reclaims control of the
timing of the reboot, behaving as if the update attempt was not given a
[RebootController] at all.