pub struct Options {
pub initiator: Option<Initiator>,
pub allow_attach_to_existing_attempt: Option<bool>,
pub should_write_recovery: Option<bool>,
pub manifest_range: Option<Range>,
/* private fields */
}Expand description
Configuration options for an update attempt.
Fields
initiator: Option<Initiator>What initiated this update attempt. Required.
allow_attach_to_existing_attempt: Option<bool>If an update is already in progress, it’s acceptable to instead attach a Monitor to that in-progress update instead of failing this request to install the update. Setting this option to true may convert situations that would have resulted in the ALREADY_IN_PROGRESS to be treated as non-error cases. A controller, if provided, will be ignored if the running update attempt already has a controller.
should_write_recovery: Option<bool>Determines if the installer should update the recovery partition if an update is available. Defaults to true.
manifest_range: Option<Range>The range of the resource indicated by the [Installer.StartUpdate] url that corresponds to
the manifest. Can only be set when the [Installer.StartUpdate] url has scheme “http[s]”,
i.e. when using the blob-based update manifest. Defaults to the entire resource.